# SeededAssetTags


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**iterable** | [**List[SeededAssetTag]**](SeededAssetTag.md) |  | 

## Example

```python
from openapi_client.models.seeded_asset_tags import SeededAssetTags

# TODO update the JSON string below
json = "{}"
# create an instance of SeededAssetTags from a JSON string
seeded_asset_tags_instance = SeededAssetTags.from_json(json)
# print the JSON string representation of the object
print SeededAssetTags.to_json()

# convert the object into a dict
seeded_asset_tags_dict = seeded_asset_tags_instance.to_dict()
# create an instance of SeededAssetTags from a dict
seeded_asset_tags_form_dict = seeded_asset_tags.from_dict(seeded_asset_tags_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


